@@ -23,6 +23,9 @@ class PyMinio:
             file_path=file_path
         )
 
+    def get_object(self, object_name):
+        return self.client.get_object(self.bucket, object_name)
+
     # 删除对象
     def remove_file(self, object_name):
         try:
