@@ -2,8 +2,8 @@ import pymysql
 from pymysql.cursors import DictCursor
 
 class Mysql:
-    def __init__(self, *, host, port, db, user, password):
-        self._connect = pymysql.connect( host=host, port=port, db=db, user=user, password=password )
+    def __init__(self, *, host, port, db, user, password, charset='utf8'):
+        self._connect = pymysql.connect( host=host, port=port, db=db, user=user, password=password, charset=charset )
         self._cursor = self._connect.cursor(DictCursor)
 
     def ping(self):
